import { Component, h, Host, Prop } from '@stencil/core';
import { addUnit, createNamespace, getSizeStyle } from '../../utils';
const [bem] = createNamespace('skeleton');
const DEFAULT_ROW_WIDTH = '100%';
const DEFAULT_LAST_ROW_WIDTH = '60%';
export class ZanSkeleton {
  constructor() {
    /**
     * 段落占位图行数
     */
    this.row = 0;
    /**
     * 段落占位图宽度，可传数组来设置每一行的宽度
     */
    this.rowWidth = DEFAULT_ROW_WIDTH;
    /**
     * 是否显示标题占位图
     */
    this.showTitle = false;
    /**
     * 是否显示头像占位图
     */
    this.showAvatar = false;
    /**
     * 是否显示骨架屏，传 false 时会展示子组件内容
     */
    this.loading = false;
    /**
     * 是否开启动画
     */
    this.showAnimate = false;
    /**
     * 是否将标题和段落显示为圆角风格
     */
    this.round = false;
    /**
     * 标题占位图宽度
     */
    this.titleWidth = '40%';
    /**
     * 头像占位图大小
     */
    this.avatarSize = '32px';
    /**
     * 头像占位图形状，可选值为 square
     */
    this.avatarShape = 'round';
    this.renderAvatar = () => {
      if (this.showAvatar) {
        return (h("div", { class: bem('avatar', this.avatarShape), style: getSizeStyle(this.avatarSize) }));
      }
    };
    this.renderTitle = () => {
      if (this.showTitle) {
        return (h("h3", { class: bem('title'), style: { width: addUnit(this.titleWidth) } }));
      }
    };
    this.getRowWidth = (index) => {
      const rowWidth = this.rowWidth;
      if (rowWidth === DEFAULT_ROW_WIDTH && index === +this.row - 1) {
        return DEFAULT_LAST_ROW_WIDTH;
      }
      if (Array.isArray(rowWidth)) {
        return rowWidth[index];
      }
      return rowWidth;
    };
    this.renderRows = () => Array(this.row)
      .fill('')
      .map((_, i) => (h("div", { class: bem('row'), style: { width: addUnit(this.getRowWidth(i)) } })));
  }
  render() {
    if (!this.loading) {
      return (h("slot", null));
    }
    return (h(Host, { class: bem({ animate: this.showAnimate, round: this.round }) },
      this.renderAvatar(),
      h("div", { class: bem('content') },
        this.renderTitle(),
        this.renderRows())));
  }
  static get is() { return "zan-skeleton"; }
  static get originalStyleUrls() { return {
    "$": ["zan-skeleton.less"]
  }; }
  static get styleUrls() { return {
    "$": ["zan-skeleton.css"]
  }; }
  static get properties() { return {
    "row": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "\u6BB5\u843D\u5360\u4F4D\u56FE\u884C\u6570"
      },
      "attribute": "row",
      "reflect": false,
      "defaultValue": "0"
    },
    "rowWidth": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "number | string | (number | string)[]",
        "resolved": "(string | number)[] | number | string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "\u6BB5\u843D\u5360\u4F4D\u56FE\u5BBD\u5EA6\uFF0C\u53EF\u4F20\u6570\u7EC4\u6765\u8BBE\u7F6E\u6BCF\u4E00\u884C\u7684\u5BBD\u5EA6"
      },
      "attribute": "row-width",
      "reflect": false,
      "defaultValue": "DEFAULT_ROW_WIDTH"
    },
    "showTitle": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "\u662F\u5426\u663E\u793A\u6807\u9898\u5360\u4F4D\u56FE"
      },
      "attribute": "show-title",
      "reflect": false,
      "defaultValue": "false"
    },
    "showAvatar": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "\u662F\u5426\u663E\u793A\u5934\u50CF\u5360\u4F4D\u56FE"
      },
      "attribute": "show-avatar",
      "reflect": false,
      "defaultValue": "false"
    },
    "loading": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "\u662F\u5426\u663E\u793A\u9AA8\u67B6\u5C4F\uFF0C\u4F20 false \u65F6\u4F1A\u5C55\u793A\u5B50\u7EC4\u4EF6\u5185\u5BB9"
      },
      "attribute": "loading",
      "reflect": false,
      "defaultValue": "false"
    },
    "showAnimate": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "\u662F\u5426\u5F00\u542F\u52A8\u753B"
      },
      "attribute": "show-animate",
      "reflect": false,
      "defaultValue": "false"
    },
    "round": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "\u662F\u5426\u5C06\u6807\u9898\u548C\u6BB5\u843D\u663E\u793A\u4E3A\u5706\u89D2\u98CE\u683C"
      },
      "attribute": "round",
      "reflect": false,
      "defaultValue": "false"
    },
    "titleWidth": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "number | string",
        "resolved": "number | string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "\u6807\u9898\u5360\u4F4D\u56FE\u5BBD\u5EA6"
      },
      "attribute": "title-width",
      "reflect": false,
      "defaultValue": "'40%'"
    },
    "avatarSize": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "number | string",
        "resolved": "number | string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "\u5934\u50CF\u5360\u4F4D\u56FE\u5927\u5C0F"
      },
      "attribute": "avatar-size",
      "reflect": false,
      "defaultValue": "'32px'"
    },
    "avatarShape": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'square' | 'round'",
        "resolved": "\"round\" | \"square\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "\u5934\u50CF\u5360\u4F4D\u56FE\u5F62\u72B6\uFF0C\u53EF\u9009\u503C\u4E3A square"
      },
      "attribute": "avatar-shape",
      "reflect": false,
      "defaultValue": "'round'"
    }
  }; }
}
